<?php
lt_include(PLOG_CLASS_PATH."class/plugin/pluginbase.class.php");
lt_include(PLOG_CLASS_PATH."class/plugin/pluginmanager.class.php");

/**
 * This class is responsible for initializing the minislideshow plugin.  The minislideshow plugin
 * creates one blog action (to generate URL for minislideshow) and two admin actions to change
 * the plugin's settings.  This class also sets up an menu option in the control center.
 *
 * @version 0.1
 * @author twu2
 */
class PluginMinislideshow extends PluginBase
{
    var $_pluginEnabled;

    function PluginMinislideshow($source = "")
    {
        $this->PluginBase($source);

        // plugin information
        $this->id = "minislideshow";
        $this->author = "twu2";
        $this->desc = "Integrates minislideshow into LifeType.";
        $this->version = "20111208";

        // locale
        $this->locales = array("en_UK", "zh_TW");

        if ($source == "admin")
            $this->initAdmin();
        else
            $this->init();
    }

    function init()
    {
        $this->registerBlogAction("minislideshow", "PluginMinislideshowShowAction");
    }

    function initAdmin()
    {
        $this->registerBlogAction("minislideshow", "PluginMinislideshowShowAction");
        $this->registerAdminAction("minislideshow", "PluginMinislideshowConfigAction");
        $this->registerAdminAction("updateMinislideshowConfig", "PluginMinislideshowUpdateConfigAction");

        // admin menu
        $menu =& Menu::getMenu();
        if(!$menu->entryExists("/menu/controlCenter/embeddedApps"))
            $this->addMenuEntry("/menu/controlCenter", "embeddedApps", "", "", true, false);
        $this->addMenuEntry("/menu/controlCenter/embeddedApps", "Minislideshow", "?op=minislideshow", "");
    }

    function register()
    {
        $blogSettings = $this->blogInfo->getSettings();
        $this->_pluginEnabled = $blogSettings->getValue("plugin_minislideshow_enabled");

        return true;
    }

    function getBlockTitle()
    {
        $blogSettings = $this->blogInfo->getSettings();

        $title = $blogSettings->getValue("minislideshow_block_title");
        return $title == '' ? $this->_locale->tr("Minislideshow_title") : $title;
    }

    function getMinislideshow()
    {
        $blogSettings = $this->blogInfo->getSettings();

        // variable for flash
        $flash_height = $blogSettings->getValue("minislideshow_flash_height");
        $flash_width = $blogSettings->getValue("minislideshow_flash_width");
        $flash_wmode = $blogSettings->getValue("minislideshow_flash_wmode");
        $flash_align = $blogSettings->getValue("minislideshow_flash_align");
        $flash_salign = $blogSettings->getValue("minislideshow_flash_salign");
        $flash_scale = $blogSettings->getValue("minislideshow_flash_scale");
        $flash_quality = $blogSettings->getValue("minislideshow_flash_quality");
        $flash_menu = $blogSettings->getValue("minislideshow_flash_menu");
        $flash_loop = $blogSettings->getValue("minislideshow_flash_loop");
        $flash_play = $blogSettings->getValue("minislideshow_flash_play");
        $flash_allowFullScreen = $blogSettings->getValue("minislideshow_flash_allowFullScreen");
        // this should be 'always'
        //$flash_allowScriptAccess = $blogSettings->getValue("minislideshow_flash_allowScriptAccess");

        // variable for minislideshow
        $noFlashUrl = $blogSettings->getValue("minislideshow_noFlashUrl");
        $xmlUrl = $blogSettings->getValue("minislideshow_xmlUrl");
        $jsUrl = $blogSettings->getValue("minislideshow_jsUrl");
        $swfUrl = $blogSettings->getValue("minislideshow_swfUrl");
        $shuffle = $blogSettings->getValue("minislideshow_shuffle");
        $showDropShadow = $blogSettings->getValue("minislideshow_showDropShadow");
        $delay = $blogSettings->getValue("minislideshow_delay");
        $transInType = $blogSettings->getValue("minislideshow_transInType");
        $transOutType = $blogSettings->getValue("minislideshow_transOutType");
        $noLink = $blogSettings->getValue("minislideshow_noLink");
        $showTitle = $blogSettings->getValue("minislideshow_showTitle");
        $titleColor = $blogSettings->getValue("minislideshow_titleColor");
        $titleBgColor = $blogSettings->getValue("minislideshow_bgColor");
        $Masks = $blogSettings->getValue("minislideshow_Masks");
        $useFull = $blogSettings->getValue("minislideshow_useFull");
        $fullscreenIcon = $blogSettings->getValue("minislideshow_fullscreenIcon");
        $showControls = $blogSettings->getValue("minislideshow_showControls");
        $autoStart = $blogSettings->getValue("minislideshow_autoStart");
        $loop = $blogSettings->getValue("minislideshow_loop");
        $preload = $blogSettings->getValue("minislideshow_preload");
        $siteInfoText = $blogSettings->getValue("minislideshow_siteInfoText");
        $siteInfoUrl = $blogSettings->getValue("minislideshow_siteInfoUrl");
        $allowScaling = $blogSettings->getValue("minislideshow_allowScaling");
        $showLoader = $blogSettings->getValue("minislideshow_showLoader");
        $mp3Url = $blogSettings->getValue("minislideshow_mp3Url");
        $customLink = $blogSettings->getValue("minislideshow_customLink");
        $linkToParent = $blogSettings->getValue("minislideshow_linkToParent");
        $useResize = $blogSettings->getValue("minislideshow_useResize");
        $fontScale = $blogSettings->getValue("minislideshow_fontScale");

        $flashVars = 'xmlUrl='.urlencode($xmlUrl);
        if ($shuffle) $flashVars .= '&shuffle=true';
        if ($showDropShadow) $flashVars .= '&showDropShadow=true';
        if ($delay != 3) $flashVars .= '&delay='.$delay;
        if ($transInType != 'Fade') $flashVars .= '&transInType='.$transInType;
        if ($transOutType != 'Fade') $flashVars .= '&transOutType='.$transOutType;
        if ($noLink) $flashVars .= '&noLink=true';
        if ($showTitle != 'false') {
            $flashVars .= '&showTitle='.$showTitle;
            if ($titleColor != 'FFFFFF') $flashVars .= '&titleColor='.$titleColor;
            if ($titleBgColor != '333333') $flashVars .= '&titleBgColor='.$titleBgColor;
        }
        if ($useFull) {
            $flashVars .= '&useFull=true';
            if ($useResize) $flashVars .= '&useResize=true';
        }
        if ($fullscreenIcon == 0) $flashVars .= '&fullscreenIcon=false';
        if ($showControls != 'autohide') $flashVars .= '&showControls='.$showControls;
        if ($Masks != 'Choose..') $flashVars .= '&'.$Masks.'=true';
        if ($autoStart == 0) $flashVars .= '&autoStart=false';
        if ($loop == 0) $flashVars .= '&loop=false';
        if ($preload != 4) $flashVars .= '&preload='.$preload;
        if ($siteInfoText != '') $flashVars .= '&siteInfoText='.urlencode($siteInfoText);
        if ($siteInfoUrl != '') $flashVars .= '&siteInfoUrl='.urlencode($siteInfoUrl);
        if ($allowScaling) $flashVars .= '&allowScaling=true';
        if ($showLoader == 0) $flashVars .= '&showLoader=false';
        if ($mp3Url != '') $flashVars .= '&mp3Url='.urlencode($mp3Url);
        if ($customLink != '') $flashVars .= '&customLink='.urlencode($customLink);
        if ($linkToParent) $flashVars .= '&linkToParent=true';
        if ($fontScale != 20) $flashVars .= '&fontScale='.$fontScale;

        $noFlashContent = false;
        if ($noFlashUrl != '') {
            $noFlashContent = file_get_contents($noFlashUrl, "r");
            $cnt = preg_match('/<img /i', $noFlashContent);
            if ($cnt !== 1)
                $noFlashContent = false;
        }
        if ($noFlashContent === false) {
            $noFlashContent = "  <a href=\"http://www.adobe.com/go/getflashplayer\">\n";
            $noFlashContent .= "    <img src=\"http://www.adobe.com/images/shared/download_buttons/get_flash_player.gif\" alt=\"Get Adobe Flash player\" />\n";
            $noFlashContent .= "  </a>\n";
        }

        if ($jsUrl !== '') {
            $html = "<script type=\"text/javascript\" src=\"$jsUrl\"></script>\n";
            $html .= "<script type=\"text/javascript\">\n";
            $html .= "  swfobject.registerObject(\"minislideshow\", \"9.0.0\");\n";
            $html .= "</script>\n";
			$html .= "<object type=\"application/x-shockwave-flash\" data=\"$swfUrl\" width=\"$flash_width\" height=\"$flash_height\">\n";
			$html .= "  <param name=\"flashvars\" value=\"$flashVars\" />\n";
            $html .= "  <param name=\"allowScriptAccess\" value=\"always\" />\n";
            if ($flash_wmode != 'Choose..') $html .= "  <param name=\"wmode\" value=\"$flash_wmode\" />\n";
            if ($flash_align != 'Choose..') $html .= "  <param name=\"align\" value=\"$flash_align\" />\n";
            if ($flash_salign != 'Choose..') $html .= "  <param name=\"salign\" value=\"$flash_salign\" />\n";
            if ($flash_scale != 'Choose..') $html .= "  <param name=\"scale\" value=\"$flash_scale\" />\n";
            if ($flash_quality != 'Choose..') $html .= "  <param name=\"quality\" value=\"$flash_quality\" />\n";
            if ($flash_menu != 'Choose..') $html .= "  <param name=\"menu\" value=\"$flash_menu\" />\n";
            if ($flash_loop != 'Choose..') $html .= "  <param name=\"loop\" value=\"$flash_loop\" />\n";
            if ($flash_play != 'Choose..') $html .= "  <param name=\"play\" value=\"$flash_play\" />\n";
            if ($flash_allowFullScreen != 'Choose..') $html .= "  <param name=\"allowFullScreen\" value=\"$flash_allowFullScreen\" />\n";
            $html .= $noFlashContent;
			$html .= "</object>\n";
            // for IE here
			$html .= "  <!--[if IE]>\n";
            $html .= "<object classid=\"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\" width=\"$flash_width\" height=\"$flash_height\" id=\"minislideshow\">\n";
			$html .= "  <param name=\"movie\" value=\"$swfUrl\" />\n";
			$html .= "  <param name=\"flashvars\" value=\"$flashVars\" />\n";
            $html .= "  <param name=\"allowScriptAccess\" value=\"always\" />\n";
            if ($flash_wmode != 'Choose..') $html .= "  <param name=\"wmode\" value=\"$flash_wmode\" />\n";
            if ($flash_align != 'Choose..') $html .= "  <param name=\"align\" value=\"$flash_align\" />\n";
            if ($flash_salign != 'Choose..') $html .= "  <param name=\"salign\" value=\"$flash_salign\" />\n";
            if ($flash_scale != 'Choose..') $html .= "  <param name=\"scale\" value=\"$flash_scale\" />\n";
            if ($flash_quality != 'Choose..') $html .= "  <param name=\"quality\" value=\"$flash_quality\" />\n";
            if ($flash_menu != 'Choose..') $html .= "  <param name=\"menu\" value=\"$flash_menu\" />\n";
            if ($flash_loop != 'Choose..') $html .= "  <param name=\"loop\" value=\"$flash_loop\" />\n";
            if ($flash_play != 'Choose..') $html .= "  <param name=\"play\" value=\"$flash_play\" />\n";
            if ($flash_allowFullScreen != 'Choose..') $html .= "  <param name=\"allowFullScreen\" value=\"$flash_allowFullScreen\" />\n";
            $html .= $noFlashContent;
			$html .= "</object>\n";
			$html .= "<![endif]-->\n";
        }
        else {
            $html  = "<embed src=\"$swfUrl\"\n";
            $html .= "       width=\"$flash_width\"\n";
            $html .= "       height=\"$flash_height\"\n";
            $html .= "       pluginspage=\"http://www.macromedia.com/go/getflashplayer\"\n";
            $html .= "       type=\"application/x-shockwave-flash\"\n";
            $html .= "       name=\"minislideshow\"\n";
            $html .= "       flashVars=\"$flashVars\">\n";
            $html .= "       allowScriptAccess=\"always\"\n";
            if ($flash_wmode != 'Choose..') $html .= "       wmode=\"$flash_wmode\">\n";
            if ($flash_align != 'Choose..') $html .= "       align=\"$flash_align\">\n";
            if ($flash_salign != 'Choose..') $html .= "       salign=\"$flash_salign\">\n";
            if ($flash_scale != 'Choose..') $html .= "       scale=\"$flash_scale\">\n";
            if ($flash_quality != 'Choose..') $html .= "       quality=\"$flash_quality\">\n";
            if ($flash_menu != 'Choose..') $html .= "       menu=\"$flash_menu\">\n";
            if ($flash_loop != 'Choose..') $html .= "       loop=\"$flash_loop\">\n";
            if ($flash_play != 'Choose..') $html .= "       play=\"$flash_play\">\n";
            if ($flash_allowFullScreen != 'Choose..') $html .= "       allowFullScreen=\"$flash_allowFullScreen\">\n";
            $html .= "</embed>\n";
            $html .= "<noembed>\n";
            $html .= $noFlashContent;
            $html .= "</noembed>\n";
        }

        return $html;
    }

    function isEnabled()
    {
        return $this->_pluginEnabled;
    }
}
?>
